@@ -4,7 +4,7 @@ package POE::Declare::Meta::Timeout;
 
 =head1 NAME
 
-POE::Declare::Meta::Timeout - A named timeout event with support methods
+POE::Declare::Meta::Timeout - A named timeout with generated support methods
 
 =head1 SYNOPSIS
 
@@ -46,14 +46,15 @@ use POE::Declare::Meta::Event ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.22';
+	$VERSION = '0.25';
 	@ISA     = 'POE::Declare::Meta::Event';
 }
 
-use Class::XSAccessor
+use Class::XSAccessor {
 	getters => {
 		delay => 'delay',
-	};
+	},
+};
 
 
 
@@ -151,7 +152,7 @@ L<POE>, L<POE::Declare>
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2009 Adam Kennedy.
+Copyright 2006 - 2010 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
