@@ -4,15 +4,15 @@ package POE::Declare::Object;
 
 =head1 NAME
 
-POE::Declare::Object - Base object for POE::Declare classes
+POE::Declare::Object - Base class for all POE::Declare classes
 
 =head1 DESCRIPTION
 
-L<POE::Declare::Object> provides the base package that delivers the core
+L<POE::Declare::Object> provides the base package that delivers core
 functionality for all instantiated L<POE::Declare> objects.
 
 Functionality and methods defined here are available in all L<POE::Declare>
-objects.
+classes.
 
 =head1 METHODS
 
@@ -31,7 +31,7 @@ use POE::Declare ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.22';
+	$VERSION = '0.25';
 }
 
 # Inside-out storage of internal values
@@ -605,6 +605,14 @@ after the SUPER call.
 
 sub _start : Event {
 	$ID{Scalar::Util::refaddr($_[HEAP])} = $_[SESSION]->ID;
+
+	# Cheaper to do this blind detach rather than testing first to
+	# make sure we have a session as a parent.
+	SCOPE: {
+		local $!; 
+		$poe_kernel->detach_myself;
+	}
+
 	$poe_kernel->call( $_[SESSION], '_alias_set');
 }
 
@@ -721,7 +729,7 @@ L<POE>, L<POE::Declare>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2009 Adam Kennedy.
+Copyright 2006 - 2010 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
